@@ -6,7 +6,7 @@ use warnings;
 use HTML::Entities;
 use Tie::Function;
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 # -----------------------------------------------
 
@@ -26,15 +26,45 @@ HTML::Entities::Interpolate - Call HTML::Entities::encode_entities, via a hash,
 
 =head1 Synopsis
 
+This is scripts/synopsis.pl:
+
+	#!/usr/bin/env perl
+
+	use strict;
+	use warnings;
+
 	use HTML::Entities::Interpolate;
 
-	print qq{<input name="data" value="$Entitize{$old_data}">\n};
+	# ------------------------------
 
-	print qq{The full text of the block is <pre>$Entitize{$block}</pre>\n};
+	my($block_1) = '<p>Para One</p>';
+	my($block_2) = "<p align='center'>Para Two</p>";
+	my($block_3) = 'http://tipjar.com/bin/test?foo=bar&reg=inald';
+	my($block_4) = $Entitize{$block_3};
 
-	print $Entitize{<<EOF};
-	Check out the web page at http://tipjar.com/bin/test?foo=bar&reg=inald
-	EOF
+	print <<EOS;
+	<html>
+		<head>
+			<title>Test HTML::Entities::Interpolate</title>
+		</head>
+		<body>
+			<h1 align='center'>HTML::Entities::Interpolate</h1>
+			<form action='#'>
+			<table align='center'>
+			<tr>
+				<td align='center'>Input: <input name='data' value='$Entitize{$block_1}'></td>
+			</tr>
+			<tr>
+				<td align='center'><br>The full text of the block is <pre>$Entitize{$block_2}</pre></td>
+			</tr>
+			<tr>
+				<td align='center'><br>Check out the web page at: <a href='$block_3'>$block_4</a></td>
+			</tr>
+			</table>
+			</form>
+		</body>
+	</html>
+	EOS
 
 =head1 Description
 
